@@ -44,7 +44,7 @@ namespace netxs::console
             }
         }
 
-        cell const& operator[](uint8_t k) const
+        cell const& operator [] (uint8_t k) const
         {
             return grade[k];
         }
@@ -75,7 +75,7 @@ namespace netxs::console
         rect client;
 
     public:
-        using span = std::span<cell>;
+        using span = std::span<cell const>;
 
         core()                         = default;
         core(core&&)                   = default;
@@ -112,11 +112,13 @@ namespace netxs::console
         auto& pick()                        { return canvas;             }
         auto  iter()                        { return canvas.begin();     }
         auto  iend()                        { return canvas.end();       }
+        auto  iter() const                  { return canvas.begin();     }
+        auto  iend() const                  { return canvas.end();       }
         auto  test(twod const& coord) const { return region.size.inside(coord); } // core: Check the coor inside the canvas.
         auto  data(twod const& coord)       { return  data() + coord.x + coord.y * region.size.x; } // core: Return the offset of the cell corresponding to the specified coordinates.
         auto  data(twod const& coord) const { return  data() + coord.x + coord.y * region.size.x; } // core: Return the const offset value of the cell.
         auto& data(size_t offset)           { return*(data() + offset);  } // core: Return the const offset value of the cell corresponding to the specified coordinates.
-        auto& operator[] (twod const& coord){ return*(data(coord));      } // core: Return reference of the canvas cell at the specified location. It is dangerous in case of layer resizing.
+        auto& operator [] (twod const& c)   { return*(data(c));          } // core: Return reference of the canvas cell at the specified location. It is dangerous in case of layer resizing.
         auto& mark()                        { return marker;             } // core: Return a reference to the default cell value.
         auto& mark() const                  { return marker;             } // core: Return a reference to the default cell value.
         auto& mark(cell const& c)           { marker = c; return marker; } // core: Set the default cell value.
@@ -186,12 +188,17 @@ namespace netxs::console
             marker.link(my);
         }
         template<class P>
-        void each(P proc) // core: Exec a proc for each cell.
+        auto each(P proc) // core: Exec a proc for each cell.
         {
+            using ret_t = std::invoke_result_t<P, cell&>;
+            static constexpr auto plain = std::is_same_v<void, ret_t>;
+
             for (auto& c : canvas)
             {
-                proc(c);
+                if constexpr (plain) proc(c);
+                else             if (proc(c)) return faux;
             }
+            if constexpr (!plain) return true;
         }
         template<class P>
         void each(rect const& region, P proc) // core: Exec a proc for each cell of the specified region.
@@ -375,44 +382,58 @@ namespace netxs::console
             static constexpr auto rev = DIRECTION == feed::fwd ? faux : true;
 
             //todo unify
-            auto empty = [&](auto txt)
+            auto is_empty = [&](auto txt)
             {
                 return txt.empty() || txt.front() == whitespace;
             };
+            auto empty = [&](auto txt)
+            {
+                return is_empty(txt);
+            };
             auto alpha = [&](auto txt)
             {
                 //todo revise (https://unicode.org/reports/tr29/#Word_Boundaries)
                 auto c = utf::letter(txt).attr.cdpoint;
-                return (c >= '0' && c <= '9' //30-39: '0'-'9'
+                return  c >= '0' && c <= '9' //30-39: '0'-'9'
                      || c >= '@' && c <= 'Z' //40-5A: '@','A'-'Z'
                      || c >= 'a' && c <= 'z' //5F,61-7A: '_','a'-'z'
                      || c == '_'             //60:    '`'
-                     || c == 0xA0    //A0  NO-BREAK SPACE (NBSP)
-                     || c >= 0xC0)   //C0-10FFFF: "À" - ...
-                     && (c < 0x2000 || c > 0x206F) // General Punctuation
-                     && (c < 0x2200 || c > 0x23FF) // Mathematical Operators
-                     && (c < 0x2500 || c > 0x25FF) // Box Drawing
-                     && (c < 0x2E00 || c > 0x2E7F) // Supplemental Punctuation
-                     && (c < 0x3000 || c > 0x303F) // CJK Symbols and Punctuation
-                     && c != 0x30FB                // U+30FB ( ・ ) KATAKANA MIDDLE DOT
-                     && (c < 0xFE50 || c > 0xFE6F) // FE50  FE6F Small Form Variants
-                     && (c < 0xFF00 || c > 0xFF0F) // Halfwidth and Fullwidth Forms
-                     && (c < 0xFF1A || c > 0xFF1F) // 
-                     && (c < 0xFF3B || c > 0xFF40) // 
-                     && (c < 0xFF5B || c > 0xFF65) // 
+                     || c == 0xA0            //A0  NO-BREAK SPACE (NBSP)
+                     || c >= 0xC0                // C0-10FFFF: "À" - ...
+                     && c < 0x2000 || c > 0x206F // General Punctuation
+                     && c < 0x2200 || c > 0x23FF // Mathematical Operators
+                     && c < 0x2500 || c > 0x25FF // Box Drawing
+                     && c < 0x2E00 || c > 0x2E7F // Supplemental Punctuation
+                     && c < 0x3000 || c > 0x303F // CJK Symbols and Punctuation
+                     && c != 0x30FB              // U+30FB ( ・ ) KATAKANA MIDDLE DOT
+                     && c < 0xFE50 || c > 0xFE6F // FE50  FE6F Small Form Variants
+                     && c < 0xFF00 || c > 0xFF0F // Halfwidth and Fullwidth Forms
+                     && c < 0xFF1A || c > 0xFF1F // 
+                     && c < 0xFF3B || c > 0xFF40 // 
+                     && c < 0xFF5B || c > 0xFF65 // 
             ;};
-            auto email = [&](auto txt)
+            auto is_email = [&](auto txt)
             {
                 return !txt.empty() && txt.front() == '@';
             };
-            auto mails = [&](auto txt)
+            auto email = [&](auto txt)
             {
                 return !txt.empty() && (alpha(txt) || txt.front() == '.');
             };
+            auto is_digit = [&](auto txt)
+            {
+                auto c = utf::letter(txt).attr.cdpoint;
+                return c >= '0' && c <= '9'
+                    || c >= 0xFF10 && c <= 0xFF19 // U+FF10 (０) FULLWIDTH DIGIT ZERO - U+FF19 (９) FULLWIDTH DIGIT NINE
+                    || c == '.';
+            };
             auto digit = [&](auto txt)
             {
                 auto c = utf::letter(txt).attr.cdpoint;
-                return c >= '.'    && c <= '9'
+                return c == '.'
+                    || c >= 'a' && c <= 'f'
+                    || c >= 'A' && c <= 'F'
+                    || c >= '0' && c <= '9'
                     || c >= 0xFF10 && c <= 0xFF19; // U+FF10 (０) FULLWIDTH DIGIT ZERO - U+FF19 (９) FULLWIDTH DIGIT NINE
             };
             auto func = [&](auto check)
@@ -435,10 +456,10 @@ namespace netxs::console
 
             coord = std::clamp(coord, dot_00, region.size - dot_11);
             auto test = data(coord)->txt();
-            digit(test) ? func(digit) :
-            email(test) ? func(mails) :
-            empty(test) ? func(empty) :
-                          func(alpha);
+            is_digit(test) ? func(digit) :
+            is_email(test) ? func(email) :
+            is_empty(test) ? func(empty) :
+                             func(alpha);
             return coord.x;
         }
         template<class P>
@@ -479,6 +500,66 @@ namespace netxs::console
             rtl ? txt.template output<true>(*this, pos, print)
                 : txt.template output<faux>(*this, pos, print);
         }
+        auto find(core const& what, si32& from) const // core: Find the substring and place its offset in &from.
+        {
+            auto size = what.canvas.size();
+            auto rest =      canvas.size() - from;
+            if (!size || size > rest) return faux;
+
+            size--;
+            auto head = core::iter();
+            auto tail = core::iend() - size;
+            auto iter = head + from;
+            auto base = what.core::iter();
+            auto dest = base;
+            auto&test =*base;
+            while (iter != tail)
+            {
+                if (test.same_txt(*iter++))
+                {
+                    auto init = iter;
+                    auto stop = iter + size;
+                    while (init != stop && init->same_txt(*++dest))
+                    {
+                        ++init;
+                    }
+
+                    if (init == stop)
+                    {
+                        from = static_cast<si32>(std::distance(head, iter)) - 1;
+                        return true;
+                    }
+                    else dest = base;
+                }
+            }
+            return faux;
+        }
+        auto toxy(si32 offset) const // core: Convert offset to coor.
+        {
+            assert(canvas.size() <= std::numeric_limits<si32>::max());
+            auto maxs = static_cast<si32>(canvas.size());
+            if (!maxs) return dot_00;
+            offset = std::clamp(offset, 0, maxs - 1);
+            return twod{ offset % region.size.x,
+                         offset / region.size.x };
+        }
+        auto line(si32 from, si32 upto) const // core: Get stripe.
+        {
+            if (from > upto) std::swap(from, upto);
+            assert(canvas.size() <= std::numeric_limits<si32>::max());
+            auto maxs = static_cast<si32>(canvas.size());
+            from = std::clamp(from, 0, maxs - 1);
+            upto = std::clamp(upto, 0, maxs);
+            auto size = upto - from;
+            return core{ span{ canvas.data() + from, static_cast<size_t>(size) }, { size, 1 }};
+        }
+        auto line(twod p1, twod p2) const // core: Get stripe.
+        {
+            if (p1.y > p2.y || (p1.y == p2.y && p1.x > p2.x)) std::swap(p1, p2);
+            auto from = p1.x + p1.y * region.size.x;
+            auto upto = p2.x + p2.y * region.size.x + 1;
+            return line(from, upto);
+        }
         void operator += (core const& src) // core: Append specified canvas.
         {
             //todo inbody::RTL
@@ -946,6 +1027,10 @@ namespace netxs::console
     public:
         using core::core;
 
+        rich(core&& s)
+            : core{ std::forward<core>(s) }
+        { }
+
         auto length() const                                     { return size().x;                         }
         auto shadow() const                                     { return shot{ *this };                    }
         auto substr(si32 at, si32 width = netxs::maxsi32) const { return shadow().substr(at, width);       }
@@ -1605,11 +1690,11 @@ namespace netxs::console
         auto& operator  = (view utf8) { clear(); ansi::parse(utf8, this); return *this; }
         auto& operator += (view utf8) {          ansi::parse(utf8, this); return *this; }
 
-        page ()                        = default;
-        page (page&&)                  = default;
-        page (page const&)             = default;
-        page& operator = (page const&) = default;
-        auto& operator+= (page const& p)
+        page ()                         = default;
+        page (page&&)                   = default;
+        page (page const&)              = default;
+        page& operator =  (page const&) = default;
+        auto& operator += (page const& p)
         {
             parts.insert(p.parts.begin(), p.parts.end()); // Part id should be unique across pages
             //batch.splice(std::next(layer), p.batch);
@@ -1623,7 +1708,7 @@ namespace netxs::console
             return *this;
         }
         // page: Acquire para by id.
-        auto& operator[] (si32 id)
+        auto& operator [] (si32 id)
         {
             if (netxs::on_key(parts, id))
             {
